==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QMimeData_shell.h <==
#ifndef QMIMEDATA_SHELL_H
#define QMIMEDATA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qmimedata.h>
#include <QtJambi/QtJambiAPI>
#include <QStringList>
#include <QUrl>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QMimeData_shell : public QMimeData, public QtJambiShellInterface
{
public:
    QMimeData_shell();
    ~QMimeData_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QStringList formats() const override;
    bool hasFormat(const QString& mimetype0) const override;
    QVariant retrieveData(const QString& mimetype0, QVariant::Type preferredType1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMimeData_access : public QMimeData
{
    jobject __qt_formats_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasFormat_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimetype0) const;
    jobject __qt_retrieveData_cref_QString_QVariant_Type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimetype0, jint preferredType1) const;
};

#endif // QMIMEDATA_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QMimeData_shell.h <==
#ifndef QMIMEDATA_SHELL_H
#define QMIMEDATA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qmimedata.h>
#include <QtJambi/QtJambiAPI>
#include <QStringList>
#include <QUrl>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QMimeData_shell : public QMimeData, public QtJambiShellInterface
{
public:
    QMimeData_shell();
    ~QMimeData_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QMimeData_mshell;
    friend class QMimeData_oshell;
};


class QMimeData_mshell : public QMimeData_shell
{
public:
    using QMimeData_shell::QMimeData_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QMimeData_oshell : public QMimeData_mshell
{
public:
    using QMimeData_mshell::QMimeData_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QStringList formats() const override;
    bool hasFormat(const QString& mimetype0) const override;
    QVariant retrieveData(const QString& mimetype0, QMetaType preferredType1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMimeData_access : public QMimeData
{
    jobject __qt_formats_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasFormat_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimetype0) const;
    jobject __qt_retrieveData_cref_QString_QMetaType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimetype0, QtJambiNativeID preferredType1) const;
};

#endif // QMIMEDATA_SHELL_H
